@@ -4,10 +4,6 @@ import numpy as np
 import pandas as pd
 from numpy.matlib import repmat
 from tqdm import tqdm
-from brainbox.core import TimeSeries
-from brainbox.processing import sync
-from one.api import ONE
-from brainbox.io.one import SessionLoader
 
 
 def raised_cosine(duration, nbases, binfun):
@@ -140,125 +136,6 @@ def bincount2D(x, y, xbin=0, ybin=0, xlim=None, ylim=None, weights=None):
     return r, xscale, yscale
 
 
-def load_trials_df(
-    eid,
-    one=None,
-    t_before=0.0,
-    t_after=0.2,
-    ret_wheel=False,
-    ret_abswheel=False,
-    wheel_binsize=0.02,
-    addtl_types=[],
-    trials_mask=None,
-):
-    """
-    Generate a pandas dataframe of per-trial timing information about a given session.
-    Each row in the frame will correspond to a single trial, with timing values indicating timing
-    session-wide (i.e. time in seconds since session start). Can optionally return a resampled
-    wheel velocity trace of either the signed or absolute wheel velocity.
-    The resulting dataframe will have a new set of columns, trial_start and trial_end, which define
-    via t_before and t_after the span of time assigned to a given trial.
-    (useful for bb.modeling.glm)
-    Parameters
-    ----------
-    eid : [str, UUID, Path, dict]
-        Experiment session identifier; may be a UUID, URL, experiment reference string
-        details dict or Path
-    one : one.api.OneAlyx, optional
-        one object to use for loading. Will generate internal one if not used, by default None
-    t_before : float, optional
-        Time before stimulus onset to include for a given trial, as defined by the trial_start
-        column of the dataframe. If zero, trial_start will be identical to stimOn, by default 0.
-    t_after : float, optional
-        Time after feedback to include in the trail, as defined by the trial_end
-        column of the dataframe. If zero, trial_end will be identical to feedback, by default 0.
-    ret_wheel : bool, optional
-        Whether to return the time-resampled wheel velocity trace, by default False
-    ret_abswheel : bool, optional
-        Whether to return the time-resampled absolute wheel velocity trace, by default False
-    wheel_binsize : float, optional
-        Time bins to resample wheel velocity to, by default 0.02
-    addtl_types : list, optional
-        List of additional types from an ONE trials object to include in the dataframe. Must be
-        valid keys to the dict produced by one.load_object(eid, 'trials'), by default empty.
-    trials_mask : list, optional
-        List of trial indices to include in the dataframe. If None, all trials will be included.
-    Returns
-    -------
-    pandas.DataFrame
-        Dataframe with trial-wise information. Indices are the actual trial order in the original
-        data, preserved even if some trials do not meet the maxlen criterion. As a result will not
-        have a monotonic index. Has special columns trial_start and trial_end which define start
-        and end times via t_before and t_after
-    """
-    if not one:
-        one = ONE()
-
-    if ret_wheel and ret_abswheel:
-        raise ValueError("ret_wheel and ret_abswheel cannot both be true.")
-
-    # Define which datatypes we want to pull out
-    trialstypes = [
-        "choice",
-        "probabilityLeft",
-        "feedbackType",
-        "feedback_times",
-        "contrastLeft",
-        "contrastRight",
-        "goCue_times",
-        "stimOn_times",
-    ]
-    trialstypes.extend(addtl_types)
-
-    loader = SessionLoader(one=one, eid=eid)
-    loader.load_session_data(pose=False, motion_energy=False, pupil=False, wheel=False)
-    if ret_wheel or ret_abswheel:
-        loader.load_wheel(smooth_size=0.001)
-
-    trials = loader.trials
-    starttimes = trials.stimOn_times
-    endtimes = trials.feedback_times
-    trialsdf = trials[trialstypes]
-    if trials_mask is not None:
-        trialsdf = trialsdf.loc[trials_mask]
-    trialsdf["trial_start"] = trialsdf["stimOn_times"] - t_before
-    trialsdf["trial_end"] = trialsdf["feedback_times"] + t_after
-    tdiffs = trialsdf["trial_end"] - np.roll(trialsdf["trial_start"], -1)
-    if np.any(tdiffs[:-1] > 0):
-        logging.warning(
-            f"{sum(tdiffs[:-1] > 0)} trials overlapping due to t_before and t_after "
-            "values. Try reducing one or both!"
-        )
-    if not ret_wheel and not ret_abswheel:
-        return trialsdf
-
-    wheel = loader.wheel
-    whlt, whlv = wheel.times, wheel.velocity
-    starttimes = trialsdf["trial_start"]
-    endtimes = trialsdf["trial_end"]
-    wh_endlast = 0
-    trials = []
-    for (start, end) in np.vstack((starttimes, endtimes)).T:
-        wh_startind = np.searchsorted(whlt[wh_endlast:], start) + wh_endlast
-        wh_endind = np.searchsorted(whlt[wh_endlast:], end, side="right") + wh_endlast + 4
-        wh_endlast = wh_endind
-        tr_whlvel = whlv[wh_startind:wh_endind]
-        tr_whlt = whlt[wh_startind:wh_endind] - start
-        whlseries = TimeSeries(tr_whlt, tr_whlvel, columns=["whlvel"])
-        whlsync = sync(wheel_binsize, timeseries=whlseries, interp="previous")
-        trialstartind = np.searchsorted(whlsync.times, 0)
-        trialendind = np.ceil((end - start) / wheel_binsize).astype(int)
-        trvel = whlsync.values[trialstartind : trialendind + trialstartind]
-        if np.abs((trialendind - len(trvel))) > 0:
-            raise IndexError("Mismatch between expected length of wheel data and actual.")
-        if ret_wheel:
-            trials.append(trvel)
-        elif ret_abswheel:
-            trials.append(np.abs(trvel))
-    trialsdf["wheel_velocity"] = trials
-    return trialsdf
-
-
 class SequentialSelector:
     def __init__(self, model, n_features_to_select=None, direction="forward", scoring=None):
         """
